Re: [PATCH] diff-delta: bound hash list length to avoid O(m*n) behavior
- From
Nicolas Pitre <nico@cam.org>
- Date
- Mar 4, 2006, 03:01 UTC
- Message-ID
- <Pine.LNX.4.64.0603032158250.1859@localhost.localdomain>
- In-Reply-To
- <7vfylzx7t3.fsf@assigned-by-dhcp.cox.net>
On Fri, 3 Mar 2006, Junio C Hamano wrote:
> In short, I'd love to get a tighter packing, but as it > currently stands, I do not think 5% resulting packsize reduction > warrants making 100% slower operation the default.
Agreed. Please just drop that one patch for now.
I'll rework the hash limiting patch so the 16-byte block version behaves better with the large 20MB files.
Nicolas